@@ -6,7 +6,7 @@ package Mite::Compiled;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007002';
+our $VERSION   = '0.007003';
 
 use Path::Tiny;
 
@@ -27,19 +27,21 @@ has source =>
   isa           => MiteSource,
   # avoid a circular dep with Mite::Source
   weak_ref      => true,
-  required      => true;
+  required      => true,
+  handles       => [ qw( classes class_order ) ];
 
 sub compile {
     my $self = shift;
 
     my $code;
-    for my $class (values %{$self->classes}) {
+    for my $class_name ( @{ $self->class_order } ) {
+        my $class = $self->classes->{$class_name};
 
         # Only supported by Type::Tiny 1.013_001 but no harm
         # in doing this anyway.
         local $Type::Tiny::SafePackage = sprintf 'package %s;',
             eval { $self->source->project->config->data->{shim} }
-            // do { $class->name . '::__SAFE_NAMESPACE__' };
+            // do { $class_name . '::__SAFE_NAMESPACE__' };
 
         $code .= $class->compile;
     }
@@ -78,15 +80,12 @@ sub remove {
     return $self->file->remove;
 }
 
-sub classes {
-    my $self = shift;
-
-    return $self->source->classes;
-}
+signature_for _source_file2compiled_file => (
+   pos => [ Defined ],
+);
 
 sub _source_file2compiled_file {
-    state $sig = sig_pos( Object, Defined );
-    my ( $self, $source_file ) = &$sig;
+    my ( $self, $source_file ) = @_;
 
     # Changes here must be coordinated with Mite.pm
     return $source_file . '.mite.pm';
