@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007002";
+    our $MITE_VERSION = "0.007003";
 
     BEGIN {
         require Scalar::Util;
@@ -346,5 +346,49 @@
         };
     }
 
+    sub _assert_blessed_source {
+        my $object = do { $_[0]{"source"} };
+        blessed($object) or croak("source is not a blessed object");
+        $object;
+    }
+
+    # Delegated methods for source
+    sub class_order { shift->_assert_blessed_source->class_order(@_) }
+    sub classes     { shift->_assert_blessed_source->classes(@_) }
+
+    our %SIGNATURE_FOR;
+
+    $SIGNATURE_FOR{"_source_file2compiled_file"} = sub {
+        my $__NEXT__ = shift;
+
+        my ( %tmp, $tmp, @head );
+
+        @_ == 2
+          or croak(
+            "Wrong number of parameters in signature for %s: %s, got %d",
+            "_source_file2compiled_file",
+            "expected exactly 2 parameters",
+            scalar(@_)
+          );
+
+        @head = splice( @_, 0, 1 );
+
+        # Parameter $head[0] (type: Defined)
+        ( defined( $head[0] ) )
+          or croak(
+"Type check failed in signature for _source_file2compiled_file: %s should be %s",
+            "\$_[0]", "Defined"
+          );
+
+        # Parameter $_[0] (type: Defined)
+        ( defined( $_[0] ) )
+          or croak(
+"Type check failed in signature for _source_file2compiled_file: %s should be %s",
+            "\$_[1]", "Defined"
+          );
+
+        return ( &$__NEXT__( @head, @_ ) );
+    };
+
     1;
 }
