@@ -6,7 +6,7 @@ package Mite::Project;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007002';
+our $VERSION   = '0.007003';
 
 has sources =>
   is            => ro,
@@ -84,9 +84,8 @@ my $parse_mm_args = sub {
 };
 
 # This is the shim Mite.pm uses when compiling.
-sub inject_mite_functions {
-    state $sig = sig_named(
-        { head => [ Object ], named_to_list => true },
+signature_for inject_mite_functions => (
+    named => [
         package   => Any,
         file      => Any,
         kind      => Str,        { default => 'class' },
@@ -94,8 +93,12 @@ sub inject_mite_functions {
         shim      => Str,
         x_source  => Optional[Object],
         x_pkg     => Optional[Object],
-    );
-    my ( $self, $package, $file, $kind, $arg, $shim, $source, $pkg, $moresubs ) = &$sig;
+    ],
+    named_to_list => true,
+);
+
+sub inject_mite_functions {
+    my ( $self, $package, $file, $kind, $arg, $shim, $source, $pkg, $moresubs ) = @_;
     my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
 
     my $fake_ns = $self->can('_module_fakeout_namespace') && $self->_module_fakeout_namespace;
@@ -180,7 +183,14 @@ sub inject_mite_functions {
     } if $requested->( 'with', 1 );
 
     *{ $package .'::signature_for' } = sub {
-        $pkg->add_method_signature( @_ );
+        my $name = shift;
+        if ( $name =~ /^\+/ ) {
+            $name =~ s/^\+//;
+            $pkg->extend_method_signature( $name, @_ );
+        }
+        else {
+            $pkg->add_method_signature( $name, @_ );
+        }
         return;
     } if $requested->( 'signature_for', 1 );
 
@@ -254,9 +264,12 @@ sub write_mites {
     return;
 }
 
+signature_for load_files => (
+    pos => [ ArrayRef, 0 ],
+);
+
 sub load_files {
-    state $sig = sig_pos( 1, ArrayRef, 0 );
-    my ( $self, $files, $inc_dir ) = &$sig;
+    my ( $self, $files, $inc_dir ) = @_;
 
     local $ENV{MITE_COMPILE} = 1;
     local @INC = @INC;
@@ -360,9 +373,12 @@ sub clean_shim {
 }
 
 # Recursively gather all the pm files in a directory
+signature_for _recurse_directory => (
+    pos => [ Path, CodeRef ],
+);
+
 sub _recurse_directory {
-    state $sig = sig_pos( Object, Path, CodeRef );
-    my ( $self, $dir, $check ) = &$sig;
+    my ( $self, $dir, $check ) = @_;
 
     my @pm_files;
 
