@@ -6,7 +6,7 @@ package Mite::Role;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007002';
+our $VERSION   = '0.007003';
 
 use Path::Tiny;
 use B ();
@@ -168,9 +168,12 @@ sub project {
     return $self->source->project;
 }
 
+signature_for add_attributes => (
+    pos => [ slurpy ArrayRef[InstanceOf['Mite::Attribute']] ],
+);
+
 sub add_attributes {
-    state $sig = sig_pos( Object, slurpy ArrayRef[InstanceOf['Mite::Attribute']] );
-    my ( $self, $attributes ) = &$sig;
+    my ( $self, $attributes ) = @_;
 
     for my $attribute (@$attributes) {
         $self->attributes->{ $attribute->name } = $attribute;
@@ -448,6 +451,8 @@ sub _compile_method_signatures {
     my $code = "our \%SIGNATURE_FOR;\n\n";
 
     for my $name ( sort keys %sigs ) {
+        my $guard = $sigs{$name}->locally_set_compiling_class( $self );
+
         $code .= sprintf(
             '$SIGNATURE_FOR{%s} = %s;' . "\n\n",
             B::perlstring( $name ),
